@@ -35,16 +35,26 @@ BEGIN
     );
     use constant BREAK_LOOP => \"BREAK";
     use constant HAS_THREADS => ( $Config{useithreads} && $INC{'threads.pm'} );
+    our( $ERRORS, $RETURN );
     if( HAS_THREADS )
     {
         require threads;
         require threads::shared;
         threads->import();
         threads::shared->import();
+    
+        my %err :shared;
+        my %ret :shared;
+    
+        $ERRORS = \%err;
+        $RETURN = \%ret;
+    }
+    else
+    {
+        $ERRORS = {};
+        $RETURN = {};
     }
     $DEBUG  = 0;
-    $ERRORS = {};
-    $RETURN = {};
     our $VERSION = 'v2.2.1';
 };
 
@@ -322,9 +332,9 @@ sub error
         }
 
         $o = $ex_class->new( $args );
-        if( HAS_THREADS )
+        if( HAS_THREADS && is_shared( $ERRORS ) )
         {
-            lock( $ERROR );
+            lock( $ERRORS );
             $ERRORS->{ $addr } = $ERROR = $o;
         }
         else
@@ -1199,6 +1209,18 @@ sub DESTROY
     my $id = Scalar::Util::refaddr( $self );
     CORE::delete( $ERRORS->{ $id } );
     CORE:delete( $RETURN->{ $id } );
+    if( HAS_THREADS && is_shared( $ERRORS ) )
+    {
+        lock( $ERRORS );
+        lock( $RETURN );
+        CORE::delete( $ERRORS->{ $id } );
+        CORE:delete( $RETURN->{ $id } );
+    }
+    else
+    {
+        CORE::delete( $ERRORS->{ $id } );
+        CORE:delete( $RETURN->{ $id } );
+    }
     return( $self );
 }
 
