@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## Module Generic - ~/lib/Module/Generic/DateTime.pm
-## Version v0.6.0
-## Copyright(c) 2023 DEGUEST Pte. Ltd.
+## Version v0.6.1
+## Copyright(c) 2025 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2021/03/20
-## Modified 2025/04/19
+## Modified 2025/04/20
 ## All rights reserved
 ## 
 ## This program is free software; you can redistribute  it  and/or  modify  it
@@ -30,7 +30,9 @@ BEGIN
     if( HAS_THREADS )
     {
         require threads;
-        import threads;
+        require threads::shared;
+        threads->import();
+        threads::shared->import();
     }
     use overload (
         q{""}   => sub{ $_[0]->{dt}->stringify },
@@ -66,7 +68,7 @@ BEGIN
         )?
     )?
     /x;
-    our $VERSION = 'v0.6.0';
+    our $VERSION = 'v0.6.1';
 };
 
 BEGIN
@@ -353,7 +355,6 @@ sub op
         {
             if( HAS_THREADS )
             {
-                require threads::shared;
                 lock( $HAS_LOCAL_TZ );
                 # try-catch
                 local $@;
@@ -517,7 +518,6 @@ sub op_minus_plus
             {
                 if( HAS_THREADS )
                 {
-                    require threads::shared;
                     lock( $HAS_LOCAL_TZ );
                     # try-catch
                     local $@;
@@ -1205,7 +1205,7 @@ Module::Generic::DateTime - A DateTime wrapper for enhanced features
 
 =head1 VERSION
 
-    v0.6.0
+    v0.6.1
 
 =head1 DESCRIPTION
 
