@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## Module Generic - ~/lib/Module/Generic/File/Mmap.pm
-## Version v0.1.4
-## Copyright(c) 2024 DEGUEST Pte. Ltd.
+## Version v0.1.5
+## Copyright(c) 2025 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2022/07/26
-## Modified 2025/03/12
+## Modified 2025/04/23
 ## All rights reserved
 ## 
 ## This program is free software; you can redistribute  it  and/or  modify  it
@@ -23,7 +23,7 @@ BEGIN
     use JSON 4.03;
     use Module::Generic::File qw( file sys_tmpdir );
     our $HAS_CACHE_MMAP = 0;
-    our $VERSION = 'v0.1.4';
+    our $VERSION = 'v0.1.5';
 };
 
 use strict;
@@ -53,6 +53,11 @@ sub init
     $self->SUPER::init( @_ ) || return( $self->pass_error );
     my $tmpdir = sys_tmpdir();
     $self->{_cache_dir} = $tmpdir->child( 'mmap_data' );
+    if( $self->{_cache_dir}->exists && !$self->{_cache_dir}->can_write )
+    {
+        warn( "You do not have write permission to the mmap data directory $self->{_cache_dir}" );
+    }
+
     # A cache file will be provided either by the user, either by us with the open() method.
     if( my $f = $self->cache_file )
     {
@@ -805,7 +810,7 @@ Module::Generic::File::Mmap - MMap File Class
 
 =head1 VERSION
 
-    v0.1.4
+    v0.1.5
 
 L<Module::Generic::File::Mmap> implements a Mmap cache mechanism using L<Cache::FastMmap>, which is an XS module. The api is very similar to its counterpart with L<Module::Generic::File::Cache> and L<Module::Generic::SharedMem>, but has the advantage of sharing data over a file like L<Module::Generic::File::Cache>, but using Mmap and being very fast.
 
