@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## Module Generic - ~/lib/Module/Generic/Finfo.pm
-## Version v0.5.0
-## Copyright(c) 2023 DEGUEST Pte. Ltd.
+## Version v0.5.1
+## Copyright(c) 2025 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2021/05/20
-## Modified 2025/04/19
+## Modified 2025/04/20
 ## All rights reserved
 ## 
 ## This program is free software; you can redistribute  it  and/or  modify  it
@@ -25,7 +25,6 @@ BEGIN
     eval( "use File::MMagic::XS 0.09008" );
     our $HAS_FILE_MMAGIC_XS = $@ ? 0 : 1;
     use Module::Generic::Null;
-    # use Nice::Try;
     use Want;
     use overload (
         q{""}    => sub    { $_[0]->{filepath} },
@@ -69,11 +68,13 @@ BEGIN
     if( HAS_THREADS )
     {
         require threads;
-        import threads;
+        require threads::shared;
+        threads->import();
+        threads::shared->import();
     }
     our %EXPORT_TAGS = ( all => [qw( FILETYPE_NOFILE FILETYPE_REG FILETYPE_DIR FILETYPE_CHR FILETYPE_BLK FILETYPE_PIPE FILETYPE_LNK FILETYPE_SOCK FILETYPE_UNKFILE )] );
     our @EXPORT_OK = qw( FILETYPE_NOFILE FILETYPE_REG FILETYPE_DIR FILETYPE_CHR FILETYPE_BLK FILETYPE_PIPE FILETYPE_LNK FILETYPE_SOCK FILETYPE_UNKFILE );
-    our $VERSION = 'v0.5.0';
+    our $VERSION = 'v0.5.1';
 };
 
 use v5.26.1;
@@ -428,7 +429,6 @@ sub _datetime
     {
         if( HAS_THREADS )
         {
-            require threads::shared;
             lock( $HAS_LOCAL_TZ );
             # try-catch
             local $@;
@@ -629,7 +629,7 @@ Module::Generic::Finfo - File Info Object Class
 
 =head1 VERSION
 
-    v0.5.0
+    v0.5.1
 
 =head1 DESCRIPTION
 
