@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## Module Generic - ~/lib/Module/Generic/Scalar.pm
-## Version v1.4.1
+## Version v1.4.2
 ## Copyright(c) 2025 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2021/03/20
-## Modified 2025/04/20
+## Modified 2025/04/22
 ## All rights reserved
 ## 
 ## This program is free software; you can redistribute  it  and/or  modify  it
@@ -80,16 +80,24 @@ BEGIN
         fallback => 1,
     );
     use constant HAS_THREADS => ( $Config{useithreads} && $INC{'threads.pm'} );
+    our $ERRORS;
     if( HAS_THREADS )
     {
         require threads;
         require threads::shared;
         threads->import();
         threads::shared->import();
+    
+        my %err :shared;
+    
+        $ERRORS = \%err;
+    }
+    else
+    {
+        $ERRORS = {};
     }
     $DEBUG = 0;
-    $ERRORS = {};
-    our $VERSION = 'v1.4.1';
+    our $VERSION = 'v1.4.2';
 };
 
 use v5.26.1;
@@ -341,7 +349,17 @@ sub error
             # We have to die, because we have an error within another error
             die( "${class}\::error() is unable to load exception class \"$ex_class\": $@" ) if( $@ );
         }
-        $o = $ERRORS->{ $addr } = $ERROR = $ex_class->new( $args );
+        my $o = $ex_class->new( $args );
+        if( HAS_THREADS && is_shared( $ERRORS ) )
+        {
+            lock( $ERRORS );
+            lock( $ERROR );
+            $ERRORS->{ $addr } = $ERROR = $o;
+        }
+        else
+        {
+            $ERRORS->{ $addr } = $ERROR = $o;
+        }
         local $@;
         my $enc_str = eval
         {
@@ -581,7 +599,17 @@ sub pass_error
              ( CORE::scalar( @_ ) == 2 && CORE::defined( $class ) ) 
            ) )
     {
-        $ERRORS->{ $addr } = $ERROR = ( CORE::defined( $class ) ? bless( $err => $class ) : $err );
+        my $o = ( CORE::defined( $class ) ? bless( $err => $class ) : $err );
+        if( HAS_THREADS && is_shared( $ERRORS ) )
+        {
+            lock( $ERRORS );
+            lock( $ERROR );
+            $ERRORS->{ $addr } = $ERROR = $o;
+        }
+        else
+        {
+            $ERRORS->{ $addr } = $ERROR = $o;
+        }
     }
     # If the error provided is not an object, we call error to create one
     else
@@ -886,7 +914,15 @@ sub DESTROY
     local( $., $@, $!, $^E, $? );
     my $self = shift( @_ );
     my $addr = Scalar::Util::refaddr( $self );
-    CORE::delete( $ERRORS->{ $addr } );
+    if( HAS_THREADS && is_shared( $ERRORS ) )
+    {
+        lock( $ERRORS );
+        CORE::delete( $ERRORS->{ $addr } );
+    }
+    else
+    {
+        CORE::delete( $ERRORS->{ $addr } );
+    }
 };
 
 sub FREEZE
