@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## Module Generic - ~/lib/Module/Generic/SharedMem.pm
-## Version v0.5.1
+## Version v0.5.2
 ## Copyright(c) 2025 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2021/01/18
-## Modified 2025/04/20
+## Modified 2025/04/22
 ## All rights reserved
 ## 
 ## This program is free software; you can redistribute  it  and/or  modify  it
@@ -38,13 +38,6 @@ BEGIN
     use constant LOCK_NB        =>  4;
     use constant LOCK_UN        =>  8;
     use constant HAS_THREADS    => ( $Config{useithreads} && $INC{'threads.pm'} );
-    if( HAS_THREADS )
-    {
-        require threads;
-        require threads::shared;
-        threads->import();
-        threads::shared->import();
-    }
     # if( $^O =~ /^(?:Android|cygwin|dos|MSWin32|os2|VMS|riscos)/ )
     # Even better
     $SUPPORTED_RE = qr/IPC\/SysV/;
@@ -118,8 +111,24 @@ EOT
     $N = do { my $foo = eval { pack "L!", 0 }; $@ ? '' : '!' };
     # Array to maintain the order in which shared memory object were created, so they can
     # be removed in that order
-    $SHEM_REPO = [];
-    $ID2OBJ    = {};
+    our( $SHEM_REPO, $ID2OBJ );
+    if( HAS_THREADS )
+    {
+        require threads;
+        require threads::shared;
+        threads->import();
+        threads::shared->import();
+    
+        my @repo :shared;
+        my %id2objs :shared;
+        $SHEM_REPO = \@repo;
+        $ID2OBJ = \%id2objs;
+    }
+    else
+    {
+        $SHEM_REPO = [];
+        $ID2OBJ    = {};
+    }
     
     our @EXPORT_OK = qw(LOCK_EX LOCK_SH LOCK_NB LOCK_UN);
     our %EXPORT_TAGS = (
@@ -127,7 +136,7 @@ EOT
             lock    => [qw( LOCK_EX LOCK_SH LOCK_NB LOCK_UN )],
             'flock' => [qw( LOCK_EX LOCK_SH LOCK_NB LOCK_UN )],
     );
-    our $VERSION = 'v0.5.1';
+    our $VERSION = 'v0.5.2';
 };
 
 use v5.26.1;
@@ -527,8 +536,19 @@ sub open
     $new->serial( $self->serial );
     $new->id( $id );
     $new->semid( $semid );
-    CORE::push( @$SHEM_REPO, $id );
-    $ID2OBJ->{ $id } = $new;
+    if( HAS_THREADS && is_shared( $SHEM_REPO ) )
+    {
+        lock( $SHEM_REPO );
+        lock( $ID2OBJ );
+        CORE::push( @$SHEM_REPO, $id );
+        $ID2OBJ->{ $id } = $new;
+    }
+    else
+    {
+        CORE::push( @$SHEM_REPO, $id );
+        $ID2OBJ->{ $id } = $new;
+    }
+
     if( !defined( $new->op( @{$SEMOP_ARGS->{(LOCK_SH)}} ) ) )
     {
         return( $self->error( "Unable to set lock on sempahore: $!" ) );
@@ -727,15 +747,34 @@ sub remove
     $self->removed( $rv ? 1 : 0 );
     if( $rv )
     {
-        for( my $i = 0; $i < scalar( @$SHEM_REPO ); $i++ )
+        if( HAS_THREADS && is_shared( $SHEM_REPO ) )
         {
-            my $this_id = $SHEM_REPO->[$i];
-            my $obj = $ID2OBJ->{ $this_id };
-            if( Scalar::Util::blessed( $obj ) && $this_id eq $id )
+            lock( $SHEM_REPO );
+            lock( $ID2OBJ );
+            for( my $i = 0; $i < scalar( @$SHEM_REPO ); $i++ )
             {
-                CORE::splice( @$SHEM_REPO, $i, 1 );
-                CORE::delete( $ID2OBJ->{ $this_id } );
-                last;
+                my $this_id = $SHEM_REPO->[$i];
+                my $obj = $ID2OBJ->{ $this_id };
+                if( Scalar::Util::blessed( $obj ) && $this_id eq $id )
+                {
+                    CORE::splice( @$SHEM_REPO, $i, 1 );
+                    CORE::delete( $ID2OBJ->{ $this_id } );
+                    last;
+                }
+            }
+        }
+        else
+        {
+            for( my $i = 0; $i < scalar( @$SHEM_REPO ); $i++ )
+            {
+                my $this_id = $SHEM_REPO->[$i];
+                my $obj = $ID2OBJ->{ $this_id };
+                if( Scalar::Util::blessed( $obj ) && $this_id eq $id )
+                {
+                    CORE::splice( @$SHEM_REPO, $i, 1 );
+                    CORE::delete( $ID2OBJ->{ $this_id } );
+                    last;
+                }
             }
         }
         $self->id( undef() );
