@@ -38,13 +38,6 @@ BEGIN
     use constant LOCK_NB        =>  4;
     use constant LOCK_UN        =>  8;
     use constant HAS_THREADS    => ( $Config{useithreads} && $INC{'threads.pm'} );
-    if( HAS_THREADS )
-    {
-        require threads;
-        require threads::shared;
-        threads->import();
-        threads::shared->import();
-    }
     $SUPPORTED_RE = qr/IPC\/SysV/;
     if( $Config{extensions} =~ /$SUPPORTED_RE/ && 
         $^O !~ /^(?:Android|dos|MSWin32|os2|VMS|riscos)/i &&
@@ -110,8 +103,24 @@ EOT
     $N = do { my $foo = eval { pack "L!", 0 }; $@ ? '' : '!' };
     # Array to maintain the order in which shared memory object were created, so they can
     # be removed in that order
-    $SHEM_REPO = [];
-    $ID2OBJ    = {};
+    our( $SHEM_REPO, $ID2OBJ );
+    if( HAS_THREADS )
+    {
+        require threads;
+        require threads::shared;
+        threads->import();
+        threads::shared->import();
+    
+        my @repo :shared;
+        my %id2objs :shared;
+        $SHEM_REPO = \@repo;
+        $ID2OBJ = \%id2objs;
+    }
+    else
+    {
+        $SHEM_REPO = [];
+        $ID2OBJ    = {};
+    }
     
     our @EXPORT_OK = qw(LOCK_EX LOCK_SH LOCK_NB LOCK_UN);
     our %EXPORT_TAGS = (
@@ -478,8 +487,19 @@ sub open
     $new->{_ipc_shared} = $shm;
     $new->{_sem} = $sem;
     my $id = $new->id;
-    CORE::push( @$SHEM_REPO, $id );
-    $ID2OBJ->{ $id } = $new;
+
+    if( HAS_THREADS && is_shared( $SHEM_REPO ) )
+    {
+        lock( $SHEM_REPO );
+        lock( $ID2OBJ );
+        CORE::push( @$SHEM_REPO, $id );
+        $ID2OBJ->{ $id } = $new;
+    }
+    else
+    {
+        CORE::push( @$SHEM_REPO, $id );
+        $ID2OBJ->{ $id } = $new;
+    }
 
     if( !defined( $sem->op( @{$SEMOP_ARGS->{(LOCK_SH)}} ) ) )
     {
@@ -721,15 +741,34 @@ sub remove
     }
     if( $rv )
     {
-        for( my $i = 0; $i < scalar( @$SHEM_REPO ); $i++ )
+        if( HAS_THREADS && is_shared( $SHEM_REPO ) )
         {
-            my $this_id = $SHEM_REPO->[$i];
-            my $obj = $ID2OBJ->{ $this_id };
-            if( Scalar::Util::blessed( $obj ) && $this_id eq $id )
+            lock( $SHEM_REPO );
+            lock( $ID2OBJ );
+            for( my $i = 0; $i < scalar( @$SHEM_REPO ); $i++ )
             {
-                CORE::splice( @$SHEM_REPO, $i, 1 );
-                CORE::delete( $ID2OBJ->{ $this_id } );
-                last;
+                my $this_id = $SHEM_REPO->[$i];
+                my $obj = $ID2OBJ->{ $this_id };
+                if( Scalar::Util::blessed( $obj ) && $this_id eq $id )
+                {
+                    CORE::splice( @$SHEM_REPO, $i, 1 );
+                    CORE::delete( $ID2OBJ->{ $this_id } );
+                    last;
+                }
+            }
+        }
+        else
+        {
+            for( my $i = 0; $i < scalar( @$SHEM_REPO ); $i++ )
+            {
+                my $this_id = $SHEM_REPO->[$i];
+                my $obj = $ID2OBJ->{ $this_id };
+                if( Scalar::Util::blessed( $obj ) && $this_id eq $id )
+                {
+                    CORE::splice( @$SHEM_REPO, $i, 1 );
+                    CORE::delete( $ID2OBJ->{ $this_id } );
+                    last;
+                }
             }
         }
         $self->{_ipc_shared} = undef;
